==> google-apps-meet-0.1.1.tar.gz: google-apps-meet-0.1.1/google/apps/meet_v2beta/services/conference_records_service/transports/base.py <==
# -*- coding: utf-8 -*-
# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import abc
from typing import Awaitable, Callable, Dict, Optional, Sequence, Union

import google.api_core
from google.api_core import exceptions as core_exceptions
from google.api_core import gapic_v1
from google.api_core import retry as retries
import google.auth  # type: ignore
from google.auth import credentials as ga_credentials  # type: ignore
from google.oauth2 import service_account  # type: ignore

from google.apps.meet_v2beta import gapic_version as package_version
from google.apps.meet_v2beta.types import resource, service

DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
    gapic_version=package_version.__version__
)


class ConferenceRecordsServiceTransport(abc.ABC):
    """Abstract transport class for ConferenceRecordsService."""

    AUTH_SCOPES = ()

    DEFAULT_HOST: str = "meet.googleapis.com"

    def __init__(
        self,
        *,
        host: str = DEFAULT_HOST,
        credentials: Optional[ga_credentials.Credentials] = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        quota_project_id: Optional[str] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        always_use_jwt_access: Optional[bool] = False,
        api_audience: Optional[str] = None,
        **kwargs,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]):
                 The hostname to connect to.
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is mutually exclusive with credentials.
            scopes (Optional[Sequence[str]]): A list of scopes.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                be used for service account credentials.
        """

        scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}

        # Save the scopes.
        self._scopes = scopes

        # If no credentials are provided, then determine the appropriate
        # defaults.
        if credentials and credentials_file:
            raise core_exceptions.DuplicateCredentialArgs(
                "'credentials_file' and 'credentials' are mutually exclusive"
            )

        if credentials_file is not None:
            credentials, _ = google.auth.load_credentials_from_file(
                credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
            )
        elif credentials is None:
            credentials, _ = google.auth.default(
                **scopes_kwargs, quota_project_id=quota_project_id
            )
            # Don't apply audience if the credentials file passed from user.
            if hasattr(credentials, "with_gdch_audience"):
                credentials = credentials.with_gdch_audience(
                    api_audience if api_audience else host
                )

        # If the credentials are service account credentials, then always try to use self signed JWT.
        if (
            always_use_jwt_access
            and isinstance(credentials, service_account.Credentials)
            and hasattr(service_account.Credentials, "with_always_use_jwt_access")
        ):
            credentials = credentials.with_always_use_jwt_access(True)

        # Save the credentials.
        self._credentials = credentials

        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
        if ":" not in host:
            host += ":443"
        self._host = host

    def _prep_wrapped_messages(self, client_info):
        # Precompute the wrapped methods.
        self._wrapped_methods = {
            self.get_conference_record: gapic_v1.method.wrap_method(
                self.get_conference_record,
                default_retry=retries.Retry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.list_conference_records: gapic_v1.method.wrap_method(
                self.list_conference_records,
                default_retry=retries.Retry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.get_participant: gapic_v1.method.wrap_method(
                self.get_participant,
                default_retry=retries.Retry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.list_participants: gapic_v1.method.wrap_method(
                self.list_participants,
                default_retry=retries.Retry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.get_participant_session: gapic_v1.method.wrap_method(
                self.get_participant_session,
                default_retry=retries.Retry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.list_participant_sessions: gapic_v1.method.wrap_method(
                self.list_participant_sessions,
                default_retry=retries.Retry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.get_recording: gapic_v1.method.wrap_method(
                self.get_recording,
                default_retry=retries.Retry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.list_recordings: gapic_v1.method.wrap_method(
                self.list_recordings,
                default_retry=retries.Retry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.get_transcript: gapic_v1.method.wrap_method(
                self.get_transcript,
                default_retry=retries.Retry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.list_transcripts: gapic_v1.method.wrap_method(
                self.list_transcripts,
                default_retry=retries.Retry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.get_transcript_entry: gapic_v1.method.wrap_method(
                self.get_transcript_entry,
                default_retry=retries.Retry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.list_transcript_entries: gapic_v1.method.wrap_method(
                self.list_transcript_entries,
                default_retry=retries.Retry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
        }

    def close(self):
        """Closes resources associated with the transport.

        .. warning::
             Only call this method if the transport is NOT shared
             with other clients - this may cause errors in other clients!
        """
        raise NotImplementedError()

    @property
    def get_conference_record(
        self,
    ) -> Callable[
        [service.GetConferenceRecordRequest],
        Union[resource.ConferenceRecord, Awaitable[resource.ConferenceRecord]],
    ]:
        raise NotImplementedError()

    @property
    def list_conference_records(
        self,
    ) -> Callable[
        [service.ListConferenceRecordsRequest],
        Union[
            service.ListConferenceRecordsResponse,
            Awaitable[service.ListConferenceRecordsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_participant(
        self,
    ) -> Callable[
        [service.GetParticipantRequest],
        Union[resource.Participant, Awaitable[resource.Participant]],
    ]:
        raise NotImplementedError()

    @property
    def list_participants(
        self,
    ) -> Callable[
        [service.ListParticipantsRequest],
        Union[
            service.ListParticipantsResponse,
            Awaitable[service.ListParticipantsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_participant_session(
        self,
    ) -> Callable[
        [service.GetParticipantSessionRequest],
        Union[resource.ParticipantSession, Awaitable[resource.ParticipantSession]],
    ]:
        raise NotImplementedError()

    @property
    def list_participant_sessions(
        self,
    ) -> Callable[
        [service.ListParticipantSessionsRequest],
        Union[
            service.ListParticipantSessionsResponse,
            Awaitable[service.ListParticipantSessionsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_recording(
        self,
    ) -> Callable[
        [service.GetRecordingRequest],
        Union[resource.Recording, Awaitable[resource.Recording]],
    ]:
        raise NotImplementedError()

    @property
    def list_recordings(
        self,
    ) -> Callable[
        [service.ListRecordingsRequest],
        Union[
            service.ListRecordingsResponse, Awaitable[service.ListRecordingsResponse]
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_transcript(
        self,
    ) -> Callable[
        [service.GetTranscriptRequest],
        Union[resource.Transcript, Awaitable[resource.Transcript]],
    ]:
        raise NotImplementedError()

    @property
    def list_transcripts(
        self,
    ) -> Callable[
        [service.ListTranscriptsRequest],
        Union[
            service.ListTranscriptsResponse, Awaitable[service.ListTranscriptsResponse]
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_transcript_entry(
        self,
    ) -> Callable[
        [service.GetTranscriptEntryRequest],
        Union[resource.TranscriptEntry, Awaitable[resource.TranscriptEntry]],
    ]:
        raise NotImplementedError()

    @property
    def list_transcript_entries(
        self,
    ) -> Callable[
        [service.ListTranscriptEntriesRequest],
        Union[
            service.ListTranscriptEntriesResponse,
            Awaitable[service.ListTranscriptEntriesResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def kind(self) -> str:
        raise NotImplementedError()


__all__ = ("ConferenceRecordsServiceTransport",)

==> google-apps-meet-0.1.5.tar.gz: google-apps-meet-0.1.5/google/apps/meet_v2beta/services/conference_records_service/transports/base.py <==
# -*- coding: utf-8 -*-
# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import abc
from typing import Awaitable, Callable, Dict, Optional, Sequence, Union

import google.api_core
from google.api_core import exceptions as core_exceptions
from google.api_core import gapic_v1
from google.api_core import retry as retries
import google.auth  # type: ignore
from google.auth import credentials as ga_credentials  # type: ignore
from google.oauth2 import service_account  # type: ignore

from google.apps.meet_v2beta import gapic_version as package_version
from google.apps.meet_v2beta.types import resource, service

DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
    gapic_version=package_version.__version__
)


class ConferenceRecordsServiceTransport(abc.ABC):
    """Abstract transport class for ConferenceRecordsService."""

    AUTH_SCOPES = ()

    DEFAULT_HOST: str = "meet.googleapis.com"

    def __init__(
        self,
        *,
        host: str = DEFAULT_HOST,
        credentials: Optional[ga_credentials.Credentials] = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        quota_project_id: Optional[str] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        always_use_jwt_access: Optional[bool] = False,
        api_audience: Optional[str] = None,
        **kwargs,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]):
                 The hostname to connect to (default: 'meet.googleapis.com').
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is mutually exclusive with credentials.
            scopes (Optional[Sequence[str]]): A list of scopes.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                be used for service account credentials.
        """

        scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}

        # Save the scopes.
        self._scopes = scopes

        # If no credentials are provided, then determine the appropriate
        # defaults.
        if credentials and credentials_file:
            raise core_exceptions.DuplicateCredentialArgs(
                "'credentials_file' and 'credentials' are mutually exclusive"
            )

        if credentials_file is not None:
            credentials, _ = google.auth.load_credentials_from_file(
                credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
            )
        elif credentials is None:
            credentials, _ = google.auth.default(
                **scopes_kwargs, quota_project_id=quota_project_id
            )
            # Don't apply audience if the credentials file passed from user.
            if hasattr(credentials, "with_gdch_audience"):
                credentials = credentials.with_gdch_audience(
                    api_audience if api_audience else host
                )

        # If the credentials are service account credentials, then always try to use self signed JWT.
        if (
            always_use_jwt_access
            and isinstance(credentials, service_account.Credentials)
            and hasattr(service_account.Credentials, "with_always_use_jwt_access")
        ):
            credentials = credentials.with_always_use_jwt_access(True)

        # Save the credentials.
        self._credentials = credentials

        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
        if ":" not in host:
            host += ":443"
        self._host = host

    @property
    def host(self):
        return self._host

    def _prep_wrapped_messages(self, client_info):
        # Precompute the wrapped methods.
        self._wrapped_methods = {
            self.get_conference_record: gapic_v1.method.wrap_method(
                self.get_conference_record,
                default_retry=retries.Retry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.list_conference_records: gapic_v1.method.wrap_method(
                self.list_conference_records,
                default_retry=retries.Retry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.get_participant: gapic_v1.method.wrap_method(
                self.get_participant,
                default_retry=retries.Retry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.list_participants: gapic_v1.method.wrap_method(
                self.list_participants,
                default_retry=retries.Retry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.get_participant_session: gapic_v1.method.wrap_method(
                self.get_participant_session,
                default_retry=retries.Retry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.list_participant_sessions: gapic_v1.method.wrap_method(
                self.list_participant_sessions,
                default_retry=retries.Retry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.get_recording: gapic_v1.method.wrap_method(
                self.get_recording,
                default_retry=retries.Retry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.list_recordings: gapic_v1.method.wrap_method(
                self.list_recordings,
                default_retry=retries.Retry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.get_transcript: gapic_v1.method.wrap_method(
                self.get_transcript,
                default_retry=retries.Retry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.list_transcripts: gapic_v1.method.wrap_method(
                self.list_transcripts,
                default_retry=retries.Retry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.get_transcript_entry: gapic_v1.method.wrap_method(
                self.get_transcript_entry,
                default_retry=retries.Retry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.list_transcript_entries: gapic_v1.method.wrap_method(
                self.list_transcript_entries,
                default_retry=retries.Retry(
                    initial=1.0,
                    maximum=10.0,
                    multiplier=1.3,
                    predicate=retries.if_exception_type(
                        core_exceptions.ServiceUnavailable,
                    ),
                    deadline=60.0,
                ),
                default_timeout=60.0,
                client_info=client_info,
            ),
        }

    def close(self):
        """Closes resources associated with the transport.

        .. warning::
             Only call this method if the transport is NOT shared
             with other clients - this may cause errors in other clients!
        """
        raise NotImplementedError()

    @property
    def get_conference_record(
        self,
    ) -> Callable[
        [service.GetConferenceRecordRequest],
        Union[resource.ConferenceRecord, Awaitable[resource.ConferenceRecord]],
    ]:
        raise NotImplementedError()

    @property
    def list_conference_records(
        self,
    ) -> Callable[
        [service.ListConferenceRecordsRequest],
        Union[
            service.ListConferenceRecordsResponse,
            Awaitable[service.ListConferenceRecordsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_participant(
        self,
    ) -> Callable[
        [service.GetParticipantRequest],
        Union[resource.Participant, Awaitable[resource.Participant]],
    ]:
        raise NotImplementedError()

    @property
    def list_participants(
        self,
    ) -> Callable[
        [service.ListParticipantsRequest],
        Union[
            service.ListParticipantsResponse,
            Awaitable[service.ListParticipantsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_participant_session(
        self,
    ) -> Callable[
        [service.GetParticipantSessionRequest],
        Union[resource.ParticipantSession, Awaitable[resource.ParticipantSession]],
    ]:
        raise NotImplementedError()

    @property
    def list_participant_sessions(
        self,
    ) -> Callable[
        [service.ListParticipantSessionsRequest],
        Union[
            service.ListParticipantSessionsResponse,
            Awaitable[service.ListParticipantSessionsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_recording(
        self,
    ) -> Callable[
        [service.GetRecordingRequest],
        Union[resource.Recording, Awaitable[resource.Recording]],
    ]:
        raise NotImplementedError()

    @property
    def list_recordings(
        self,
    ) -> Callable[
        [service.ListRecordingsRequest],
        Union[
            service.ListRecordingsResponse, Awaitable[service.ListRecordingsResponse]
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_transcript(
        self,
    ) -> Callable[
        [service.GetTranscriptRequest],
        Union[resource.Transcript, Awaitable[resource.Transcript]],
    ]:
        raise NotImplementedError()

    @property
    def list_transcripts(
        self,
    ) -> Callable[
        [service.ListTranscriptsRequest],
        Union[
            service.ListTranscriptsResponse, Awaitable[service.ListTranscriptsResponse]
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_transcript_entry(
        self,
    ) -> Callable[
        [service.GetTranscriptEntryRequest],
        Union[resource.TranscriptEntry, Awaitable[resource.TranscriptEntry]],
    ]:
        raise NotImplementedError()

    @property
    def list_transcript_entries(
        self,
    ) -> Callable[
        [service.ListTranscriptEntriesRequest],
        Union[
            service.ListTranscriptEntriesResponse,
            Awaitable[service.ListTranscriptEntriesResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def kind(self) -> str:
        raise NotImplementedError()


__all__ = ("ConferenceRecordsServiceTransport",)
